@@ -13,22 +13,22 @@ from rest_framework.relations import RelatedField
 from rest_framework.fields import SkipField
 from rest_framework.utils.serializer_helpers import ReturnDict, ReturnList
 
-from dynamic_rest import prefetch
-from dynamic_rest.bases import (
+from xtrm_drest import prefetch
+from xtrm_drest.bases import (
     CacheableFieldMixin,
     DynamicSerializerBase,
     resettable_cached_property
 )
-from dynamic_rest.conf import settings
-from dynamic_rest.fields import (
+from xtrm_drest.conf import settings
+from xtrm_drest.fields import (
     DynamicRelationField,
     DynamicGenericRelationField,
 )
-from dynamic_rest.links import merge_link_object
-from dynamic_rest.meta import get_model_table
-from dynamic_rest.processors import SideloadingProcessor, post_process
-from dynamic_rest.tagged import tag_dict
-from dynamic_rest.mixins import (
+from xtrm_drest.links import merge_link_object
+from xtrm_drest.meta import get_model_table
+from xtrm_drest.processors import SideloadingProcessor, post_process
+from xtrm_drest.tagged import tag_dict
+from xtrm_drest.mixins import (
     NestedCreateMixin, NestedUpdateMixin, UniqueFieldsMixin
 )
 
